#
# spec file for package portaudio
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname_c 2
%define soname_p 0

Name:           portaudio
Version:        19_20140130
Release:        294.1
Summary:        Portable Real-Time Audio Library
License:        MIT
Group:          Development/Libraries/C and C++
Url:            http://www.portaudio.com/
Source:         http://www.portaudio.com/archives/pa_stable_v%{version}.tgz
Source1:        baselibs.conf
%define lname_c	libportaudio%{soname_c}
%define lname_p	libportaudiocpp%{soname_p}
BuildRequires:  alsa-devel
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig(jack)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
PortAudio is a portable audio I/O library designed for cross-platform
support of audio. It uses a callback mechanism to request audio
processing. Audio can be generated in various formats, including 32 bit
floating point, and will be converted to the native format internally.

%package -n %lname_c
Summary:        Portable Real-Time Audio Library
Group:          System/Libraries
# portaudio was last used in openSUSE 12.1
Provides:       portaudio = %{version}
Obsoletes:      portaudio < %{version}

%description -n %lname_c
PortAudio is a portable audio I/O library designed for cross-platform
support of audio. It uses a callback mechanism to request audio
processing. Audio can be generated in various formats, including 32 bit
floating point, and will be converted to the native format internally.
%package -n %lname_p
Summary:        Portable Real-Time Audio Library
Group:          System/Libraries
# packman used to provide this
Obsoletes:      libportaudiocpp

%description -n %lname_p
PortAudio is a portable audio I/O library designed for cross-platform
support of audio. It uses a callback mechanism to request audio
processing. Audio can be generated in various formats, including 32 bit
floating point, and will be converted to the native format internally.

%package devel
Summary:        Development package for the portaudio library
Group:          Development/Languages/C and C++
Requires:       %lname_c = %{version}
Requires:       %lname_p = %{version}
Obsoletes:      libportaudiocpp-devel

%description devel
This package contains the files needed to compile programs that use the
portaudio library.

%prep
%setup -q -n portaudio
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')  
sed -i "s/__DATE__/\"$FAKE_BUILDDATE\"/" qa/loopback/src/paqa.c src/common/pa_front.c
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%H:%%M:%%S')  
sed -i "s/__TIME__/\"$FAKE_BUILDTIME\"/" qa/loopback/src/paqa.c src/common/pa_front.c
echo 'HTML_TIMESTAMP=NO' >> Doxyfile

%build
%configure --disable-static \
           --enable-cxx=yes \
           --with-alsa=yes \
           --with-jack=yes \
           --with-oss=yes
make lib/libportaudio.la %{?_smp_mflags}
make %{?_smp_mflags}
doxygen

%install
make install DESTDIR=%{?buildroot}
rm -f %{buildroot}/%{_libdir}/*.la

%post -n %lname_c -p /sbin/ldconfig
%post -n %lname_p -p /sbin/ldconfig

%postun -n %lname_c -p /sbin/ldconfig
%postun -n %lname_p -p /sbin/ldconfig

%files -n %lname_c
%defattr(-,root,root)
%{_libdir}/libportaudio.so.%{soname_c}*
%files -n %lname_p
%defattr(-,root,root)
%{_libdir}/libportaudiocpp.so.%{soname_p}*

%files devel
%defattr(-,root,root)
%doc README.txt LICENSE.txt
%doc doc/html
%{_includedir}/*
%{_libdir}/pkgconfig/*.pc
%{_libdir}/lib*.so

%changelog
* Mon Jun 29 2015 olaf@aepfle.de
- Enable libportaudiocpp
* Wed May 28 2014 crrodriguez@opensuse.org
- disable timestamps in doxygen too, make build-compare happy
* Wed Apr  9 2014 p.drouand@gmail.com
- Update to version 20140130
  + No changelog available
* Mon May  6 2013 cfarrell@suse.com
- license update: MIT
  The correct license for the package is MIT
* Mon Apr  2 2012 reddwarf@opensuse.org
- run spec_cleaner
- use full URL in Source tag
- add missing provides/obsoletes from previous rename
- use date in version number: makes more sense and otherwise the
  obsoletes of the package rename would not work
- patch __DATE__ and __TIME__ references to help build-compare
* Sun Jan 29 2012 danielzucchetto@yahoo.it
- updated to the latest stable version
  * Improvements to latency calculations: Improved defaults, allow
    very low buffer sizes, report actual latencies in PaStreamInfo
    (CoreAudio r1703 #95 #175, WMME r1717 #178, also changes to
    DirectSound and WMME)
  * ALSA: Fixed issue define SND_PCM_TSTAMP_ENABLE as
    SND_PCM_TSTAMP_MMAP if the former is undefined #153 r1691
  * AudioScience HPI: Updated support to V4.08. #197, r1760, r1761
  * ASIO: Fixed bug where host buffer size wasn’t matched to client
    framesPerBuffer when it should have been. Resolves ticket #93
    r1175
  * ASIO: PaAsio_GetAvailableLatencyValues deprecated, use
    PaAsio_GetAvailableBufferSizes. See ticket #111
  * Changed default host API selection logic: use first
    successfully initialized host api with a defined default input
    or output device. Resolves ticket #49
  * Added support for Float32 to UInt8 conversion. r1748
  * Made ring buffer params const-correct r1694
  * Changes to ring buffer memory barrier placement (needs further
    review). See r1734, r1735, r1736, r1738 for details.
  * Separated test programs into “test”, “examples”, and “qa”
    folders. #191
  * Harmonised use of #if with PA_USE_*HOSTAPI* configuration
    variables accross all host APIs r1740, #164
  * Improvements to QA tests including paqa_latency, paqa loopback
    test
  * Improvements and cleanups to doxygen documentation. Added
    Doxyfile.developer for generating internal docs.
* Mon Dec  5 2011 danielzucchetto@yahoo.it
- updated to the latest stable version (20110326)
  * Fixed a lot of bugs on all platforms
  * Fixed a lot of build system issues on all platforms (autotools,
    msvc, scons)
  * Added more support for V19 API features on many platforms
  * Added WASAPI implementation
  * Ring buffer code was generalised into pa_ringbuffer.c with
    correct memory barriers. this is now used by many host api
    implementations
  * Implemented blocking i/o for ASIO
  * Made ALSA default host API on Linux
  * Fixed stream info inputLatency and outputLatency calculations
    in a number of host APIs (r1598, r1599, r1600)
  * WMME added support for ac3+wma spdif passthrough
  * DirectSound? added support for driver-level full duplex via DX8
    DirectSoundFullDuplexCreate?
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Mon Nov 21 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
- Do shlib policy packaging
* Sun Apr 24 2011 toddrme2178@gmail.com
- Add 32bit compatibility libraries
* Tue Feb 16 2010 coolo@novell.com
- use libjack-devel (tiwai)
* Tue Jan 13 2009 crrodriguez@suse.de
- remove static libraries
* Wed Jun 18 2008 schwab@suse.de
- Remove useless SHARED_FLAGS.
* Tue Jan 15 2008 tiwai@suse.de
- updated to the latet stable version (20071207)
  * added debugging message to JACK back-end
  * fixed issue with reopening full duplex streams
  * ALSA: Pick device "default" for default input device as well
  * added PA JACK extensions for getting and setting JACK client
    name
  * do not automatically start jackd server
* Fri Apr 20 2007 tiwai@suse.de
- removed unnecessary requires
- use bz2
- move documents to devel packages
* Tue Feb 27 2007 anschneider@suse.de
- updated to the latest stable:
  * fixed alsa support
  * fixed dmix support
  * fixed Pa_OpenDefaultStream crash
  * fixed memory bug in pa_jack.c
  * fixed ph_audio_play_cbk to be called too often
* Thu Sep 21 2006 tiwai@suse.de
- updated to the latest snapshot:
  * versioned so files
  * pkgconfig support
  * reorganized src structures
  * many bugfixes
- generate devel documents using doxygen
* Fri Mar 24 2006 tiwai@suse.de
- fixed bogus assert (#159993)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Oct 12 2005 tiwai@suse.de
- removed glib* from neededforbuild.
* Thu Jun 16 2005 meissner@suse.de
- use RPM_OPT_FLAGS again.
* Mon Jan 24 2005 tiwai@suse.de
- updated to snapshot-20050124.
* Tue Nov  9 2004 tiwai@suse.de
- updated to snapshot-20041109.
- fixed the lib path for jack (bug #47590).
* Fri Mar  5 2004 tiwai@suse.de
- updated to snapshot-20040305.
* Wed Jan 14 2004 tiwai@suse.de
- initial version: v19 snapshot-20040114.
